enum Peeked<I: Iterator> {
A(I::Item),
B(I::Item),
}Expand description
Benchmarks faster than wrapping both iterators in a Peekable, probably because we can afford to impose a FusedIterator bound.
Variants